@@ -202,6 +202,10 @@ fn hdl_compute(m: &syn::Expr) -> Result<TS> {
         Expr::MethodCall(method) => hdl_method(method),
         Expr::Lit(lit) => hdl_literal(lit),
         Expr::Cast(cast) => hdl_cast(&cast),
+        Expr::Index(_ndx) => {
+            let ndx_expanded = common::fixup_ident(quote!(#m).to_string());
+            Ok(quote!(ast::VerilogExpression::Signal(#ndx_expanded.to_string())))
+        }
         _ => Err(syn::Error::new(
             m.span(),
             format!("Unsupported expression type: {:?}", m),
@@ -274,9 +278,12 @@ fn hdl_cast(cast: &syn::ExprCast) -> Result<TS> {
 
 fn hdl_call(call: &syn::ExprCall) -> Result<TS> {
     let funcname = quote!(#call).to_string();
-    if funcname.starts_with("bit_cast") || funcname.starts_with("signed_bit_cast")
-        || funcname.starts_with("signed_cast") || funcname.starts_with("unsigned_cast")
-        || funcname.starts_with("bits") || funcname.starts_with("Bits")
+    if funcname.starts_with("bit_cast")
+        || funcname.starts_with("signed_bit_cast")
+        || funcname.starts_with("signed_cast")
+        || funcname.starts_with("unsigned_cast")
+        || funcname.starts_with("bits")
+        || funcname.starts_with("Bits")
     {
         hdl_compute(&call.args[0])
     } else if funcname.starts_with("all_true") {
@@ -285,8 +292,13 @@ fn hdl_call(call: &syn::ExprCall) -> Result<TS> {
         ast::VerilogExpression::Unary(ast::VerilogOpUnary::All, Box::new(#arg))
         }))
     } else {
-        Err(syn::Error::new(call.span(),
-                            format!("Unsupported function {} called for HDL conversion", funcname)))
+        Err(syn::Error::new(
+            call.span(),
+            format!(
+                "Unsupported function {} called for HDL conversion",
+                funcname
+            ),
+        ))
     }
 }
 
